@@ -3,6 +3,9 @@ import Intents
 
 
 class TestINCallRecordType(TestCase):
+    def test_enum_types(self):
+        self.assertIsEnumType(Intents.INCallRecordType)
+
     @min_os_level("10.12")
     def testConstants(self):
         self.assertEqual(Intents.INCallRecordTypeUnknown, 0)
